@@ -10,7 +10,6 @@ from pathlib import Path
 import argparse
 import subprocess
 
-
 parser = argparse.ArgumentParser()
 parser.add_argument("fontmake", type=str, help="The path to fontmake.")
 parser.add_argument("psautohint", type=str, help="The path to psautohint.")
@@ -21,10 +20,9 @@ args = parser.parse_args()
 source = Path(args.font_source).resolve()
 output_dir = Path(args.output_dir)
 
-subprocess.run([
-    args.fontmake, "-g", source, "-i", "-o", "otf", "--verbose",
-    "WARNING"
-], cwd=output_dir)
+subprocess.run(
+    [args.fontmake, "-g", source, "-i", "-o", "otf", "--verbose", "WARNING"],
+    cwd=output_dir)
 
 for otf in (output_dir / "instance_otf").glob("*.otf"):
     subprocess.run([args.psautohint, "-qq", str(otf)])
